==> dataharvest-0.2.7.tar.gz: dataharvest-0.2.7/src/dataharvest/spider/toutiao_spider.py <==
from typing import Optional

from playwright.async_api import async_playwright
from playwright.sync_api import sync_playwright

from dataharvest.schema import Document
from dataharvest.spider.base import SpiderConfig
from dataharvest.spider.spider import BaseSpider


class ToutiaoSpider(BaseSpider):
    def __init__(self, config: Optional[SpiderConfig] = None):
        self._config = self._merge_config(config)

    def match(self, url: str) -> bool:
        return "www.toutiao.com/article/" in url

    def crawl(self, url: str, config: Optional[SpiderConfig] = None) -> Document:
        config = self._merge_config(config)
        with sync_playwright() as playwright:
            browser = playwright.chromium.launch(**self.convert_2_playwright_lunch_arg(config))
            page = browser.new_page()

            if config.headers:
                page.set_extra_http_headers(config.headers)

            js = """
                    Object.defineProperties(navigator, {webdriver:{get:()=>undefined}});
                    """
            page.add_init_script(js)
            page.goto(url)
            page.wait_for_load_state("networkidle", timeout=10000)
            html = page.content()
            document = Document(url=page.url, metadata={}, page_content=html)
            return document

    async def a_crawl(
        self, url: str, config: Optional[SpiderConfig] = None
    ) -> Document:
        config = self._merge_config(config)

        async with async_playwright() as p:
            browser = await p.chromium.launch(**self.convert_2_playwright_lunch_arg(config))
            page = await browser.new_page()

            if config.headers:
                await page.set_extra_http_headers(config.headers)

            js = """
                    Object.defineProperties(navigator, {webdriver:{get:()=>undefined}});
                    """
            await page.add_init_script(js)
            await page.goto(url)
            await page.wait_for_load_state("networkidle", timeout=10000)
            html = await page.content()
            await browser.close()
            return Document(url=url, metadata={}, page_content=html)

==> dataharvest-0.2.13.tar.gz: dataharvest-0.2.13/src/dataharvest/spider/toutiao_spider.py <==
from typing import Optional

from playwright.async_api import async_playwright
from playwright.sync_api import sync_playwright
from playwright_stealth import stealth_async, stealth_sync

from dataharvest.schema import Document
from dataharvest.spider.base import SpiderConfig
from dataharvest.spider.spider import BaseSpider


class ToutiaoSpider(BaseSpider):
    def __init__(self, config: Optional[SpiderConfig] = None):
        super().__init__(config)

    def match(self, url: str) -> bool:
        return "/www.toutiao.com/article/" in url

    def crawl(self, url: str, config: Optional[SpiderConfig] = None) -> Document:
        config = self._merge_config(config)
        with sync_playwright() as playwright:
            browser = playwright.chromium.launch(
                **self.convert_2_playwright_lunch_arg(config))
            page = browser.new_page()

            if config.headers:
                page.set_extra_http_headers(config.headers)

            stealth_sync(page)
            page.goto(url)
            page.wait_for_load_state("networkidle", timeout=10000)
            html = page.content()
            document = Document(url=page.url, metadata={}, page_content=html)
            return document

    async def a_crawl(
            self, url: str, config: Optional[SpiderConfig] = None
    ) -> Document:
        config = self._merge_config(config)

        async with async_playwright() as p:
            browser = await p.chromium.launch(
                **self.convert_2_playwright_lunch_arg(config))
            page = await browser.new_page()

            if config.headers:
                await page.set_extra_http_headers(config.headers)

            await stealth_async(page)
            await page.goto(url)
            await page.wait_for_load_state("networkidle", timeout=10000)
            html = await page.content()
            await browser.close()
            return Document(url=url, metadata={}, page_content=html)
